package com.fs.hisStore.mapper;

import com.fs.hisStore.domain.FsHomeArticleViewScrm;
import com.fs.hisStore.param.home.HomeArticleViewListParam;
import com.fs.hisStore.vo.home.HomeArticleViewsListVO;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 期刊阅读Mapper接口
 *
 * @author fs
 * @date 2025-05-21
 */
public interface FsHomeArticleViewScrmMapper
{
    /**
     * 查询期刊阅读
     *
     * @param viewId 期刊阅读ID
     * @return 期刊阅读
     */
    public FsHomeArticleViewScrm selectFsHomeArticleViewById(Long viewId);

    /**
     * 查询期刊阅读列表
     *
     * @param fsHomeArticleView 期刊阅读
     * @return 期刊阅读集合
     */
    public List<FsHomeArticleViewScrm> selectFsHomeArticleViewList(FsHomeArticleViewScrm fsHomeArticleView);

    /**
     * 新增期刊阅读
     *
     * @param fsHomeArticleView 期刊阅读
     * @return 结果
     */
    public int insertFsHomeArticleView(FsHomeArticleViewScrm fsHomeArticleView);

    /**
     * 修改期刊阅读
     *
     * @param fsHomeArticleView 期刊阅读
     * @return 结果
     */
    public int updateFsHomeArticleView(FsHomeArticleViewScrm fsHomeArticleView);

    /**
     * 删除期刊阅读
     *
     * @param viewId 期刊阅读ID
     * @return 结果
     */
    public int deleteFsHomeArticleViewById(Long viewId);

    /**
     * 批量删除期刊阅读
     *
     * @param viewIds 需要删除的数据ID
     * @return 结果
     */
    public int deleteFsHomeArticleViewByIds(Long[] viewIds);

    /**
     * 查询文章的阅读人员列表
     * @param param 入参
     * @return
     */
    List<HomeArticleViewsListVO> selectHomeArticleViewsList(@Param("param") HomeArticleViewListParam param);

}
